@@ -32,7 +32,7 @@ package Apache2::AMFLiteDetectionFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "4.05";
+  $VERSION= "4.06";
   my $CommonLib = new Apache2::AMFCommonLib ();
   my %MobileArray;#=$CommonLib->getMobileArray;
   my %MobileTabletArray;
@@ -47,11 +47,13 @@ package Apache2::AMFLiteDetectionFilter;
   my $checkVersion='true';
   my $mobilenable="false";
   #http://master.dl.sourceforge.net//project/mobilefilter/litetabletdetection.config
-  my $urlmobile="http://master.dl.sourceforge.net//project/mobilefilter/litemobiledetection.config";
-  my $urlTablet="http://master.dl.sourceforge.net//project/mobilefilter/litetabletdetection.config";
-  my $urlTouch="http://master.dl.sourceforge.net//project/mobilefilter/litetouchdetection.config";
-  my $urlBot="http://master.dl.sourceforge.net//project/mobilefilter/litebotdetection.config";
+  my $hostServer="http://cznic.dl.sourceforge.net/project/mobilefilter/AMFRepository/";
+  my $urlmobile=$hostServer."litemobiledetection.config";
+  my $urlTablet=$hostServer."litetabletdetection.config";
+  my $urlTouch=$hostServer."litetouchdetection.config";
+  my $urlBot=$hostServer."litebotdetection.config";
   my $bo;
+  print "----> $urlTablet";
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
   $CommonLib->printLog("-------                 APACHE MOBILE FILTER V$VERSION                  -------");
   $CommonLib->printLog("------- support http://groups.google.com/group/amf-device-detection -------");
@@ -64,8 +66,8 @@ package Apache2::AMFLiteDetectionFilter;
   }
   if ($checkVersion eq 'true') {
 	$CommonLib->printLog("Check on apchemobilefilter.org if the installed AMF is the last version");  
-        $CommonLib->printLog("Try to download http://www.apachemobilefilter.org/param/amf.config");
-	my $url="http://www.apachemobilefilter.org/param/amf.config";
+	my $url=$hostServer."amf.config";
+        $CommonLib->printLog("Try to download ".$url);
 	my $content = get ($url);
 	my $check_version=0;
 	if ($content) {
